@@ -27,11 +27,11 @@ class GraphQLPostman(BasePostman):
     assignations: Dict[str, AssignationFragment] = Field(default_factory=dict)
     reservations: Dict[str, ReservationFragment] = Field(default_factory=dict)
 
-    _res_update_queues: Dict[str, asyncio.Queue[ReservationFragment]] = {}
-    _ass_update_queues: Dict[str, asyncio.Queue[AssignationFragment]] = {}
+    _res_update_queues: Dict[str, asyncio.Queue] = {}
+    _ass_update_queues: Dict[str, asyncio.Queue] = {}
 
-    _res_update_queue: asyncio.Queue[ReservationFragment] = None
-    _ass_update_queue: asyncio.Queue[AssignationFragment] = None
+    _res_update_queue: asyncio.Queue = None
+    _ass_update_queue: asyncio.Queue = None
 
     _watch_resraces_task: asyncio.Task = None
     _watch_assraces_task: asyncio.Task = None
@@ -58,7 +58,7 @@ class GraphQLPostman(BasePostman):
         params: ReserveParamsInput = None,
         provision: str = None,
         reference: str = "default",
-    ) -> asyncio.Queue[ReservationFragment]:
+    ) -> asyncio.Queue:
         async with self._lock:
             if not self._watching:
                 await self.start_watching()
@@ -88,7 +88,7 @@ class GraphQLPostman(BasePostman):
         persist=True,
         log=False,
         reference: str = None,
-    ) -> asyncio.Queue[AssignationFragment]:
+    ) -> asyncio.Queue:
         async with self._lock:
             if not self._watching:
                 await self.start_watching()
