@@ -41,7 +41,7 @@ class StatefulPostman(BasePostman):
         params: dict = None,
         provision: str = None,
         reference: str = None,
-    ) -> asyncio.Queue[ReservationFragment]:
+    ) -> asyncio.Queue:
         reservation = await self.transport.areserve(
             node, params, provision=provision, reference=reference
         )
@@ -61,7 +61,7 @@ class StatefulPostman(BasePostman):
         args: List[Any],
         persist=True,
         log=False,
-    ) -> asyncio.Queue[AssignationFragment]:
+    ) -> asyncio.Queue:
         assignation = await self.transport.aassign(reservation, args, persist, log)
         self.assignations[assignation.assignation] = assignation
         return assignation
